VaspParser — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# VaspParser

The `pyprocar.io.vasp` is used to parse the Vasp files

`pyprocar.io.vasp.Outcar`([filename]) | A class to parse the OUTCAR file from a VASP run and extract electronic structure data.
`pyprocar.io.vasp.Poscar`([filename, rotations]) | A class to parse the POSCAR file
`pyprocar.io.vasp.Procar`([filename, ...]) | A class to parse the PROCAR file
`pyprocar.io.vasp.Kpoints`([filename, ...]) | A class to parse the KPOINTS file
`pyprocar.io.vasp.VaspXML`([filename, ...]) | A class to parse the vasprun xml file